// Importing modules from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { 
// Assigning X axis data   
  const xValue = d => d.month; 
  const xAxisLabel = 'Month';
// Assigning Y axis data 
  const yValue = d => d.cost;
  const yAxisLabel = 'Cost';
  
  const margin = { top: 40, right: 20, bottom: 38, left: 130 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  
  //  Scale for X axis
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
//  Scale for Y axis  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

// Placing the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  	
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line
//adding it to svg 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// Loading CSV data
csv('https://gist.githubusercontent.com/Mgk1255/a10200c6a34a003fd18980f8956a8c0e/raw/45ce46bee4cb0707980e4bd600370281cc001aea/linee.csv')
  .then(data => {
    data.forEach(d => {
    	d.cost = +d.cost;
//Formatting to retrieve month from the date
      d.month = d3.timeParse("%d/%m/%Y")(d.month);
    });

    render(data);
  })